@@ -22,21 +22,20 @@ class UtilsCheck(TestCase):
         env.host_string = 'hosttest'
         env.remote_python_version = 2.7
 
-
     def tearDown(self):
         env.clear()
 
-
     @patch('fabtools.require.deb.packages', return_value=Mock())
     @patch('fabtools.require.python.install', return_value=Mock())
     def test_python_pkg(self, python_install, deb_packages):
         python_pkg()
         self.assertTrue(deb_packages.called)
-        self.assertEqual(deb_packages.call_args, call(['python-dev', 'python-pip'], update=False))
+        self.assertEqual(deb_packages.call_args, call(
+            ['python-dev', 'python-pip'], update=False))
         self.assertTrue(python_install.called)
-        self.assertEqual(python_install.call_args, call('pip', upgrade=True, use_sudo=True))
-        
-        
+        self.assertEqual(
+            python_install.call_args, call('pip', upgrade=True, use_sudo=True))
+
     @patch('fabtools.python.virtualenv', return_value=Mock())
     @patch('fabric.api.cd', return_value=Mock())
     @patch('fabric.api.sudo', return_value=Mock())
@@ -55,13 +54,16 @@ class UtilsCheck(TestCase):
         self.assertEqual(api_cd.call_args, call('remote_current_path'))
 
         self.assertTrue(api_sudo.called)
-        self.assertEqual(api_sudo.call_args, call('pip install -e .', user='remote_owner', pty=False))
-   
+        self.assertEqual(api_sudo.call_args, call(
+            'pip install -e .', user='remote_owner', pty=False))
+
         self.assertTrue(python_virtualenv.called)
-        self.assertEqual(python_virtualenv.call_args, call('remote_virtualenv_dir'))
+        self.assertEqual(
+            python_virtualenv.call_args, call('remote_virtualenv_dir'))
 
         self.assertTrue(install_requirements.called)
-        self.assertEqual(install_requirements.call_args, call('requirements/goal.txt', pip_cmd='pip', use_sudo=True, upgrade=False, user='remote_owner'))
+        self.assertEqual(install_requirements.call_args, call(
+            'requirements/goal.txt', pip_cmd='pip', use_sudo=True, upgrade=False, user='remote_owner'))
 
 
 class VirtualEnvCheck(TestCase):
@@ -76,11 +78,9 @@ class VirtualEnvCheck(TestCase):
         env.remote_virtualenv_dir = "remote_virtualenv_dir"
         env.remote_owner = "remote_owner"
 
-
     def tearDown(self):
         env.clear()
 
-
     @patch('fabtools.require.files.directory', return_value=Mock())
     @patch('fabtools.require.python.virtualenv', return_value=Mock())
     def test_virtualenv(self, python_virtualenv, files_directory):
@@ -88,10 +88,9 @@ class VirtualEnvCheck(TestCase):
         virtualenv()
 
         self.assertTrue(python_virtualenv.called)
-        self.assertEqual(python_virtualenv.call_args, 
-            call('remote_virtualenv_dir', clear=False, use_sudo=True, venv_python='/usr/bin/python2.7', user='remote_owner'))
+        self.assertEqual(python_virtualenv.call_args,
+                         call('remote_virtualenv_dir', clear=False, use_sudo=True, venv_python='/usr/bin/python2.7', user='remote_owner'))
 
         self.assertTrue(files_directory.called)
-        self.assertEqual(files_directory.call_args, call('remote_virtualenv_dir', owner='remote_owner', use_sudo=True, group='remote_group'))
-
-        
\ No newline at end of file
+        self.assertEqual(files_directory.call_args, call(
+            'remote_virtualenv_dir', owner='remote_owner', use_sudo=True, group='remote_group'))
